@@ -109,6 +109,8 @@ class MenuItemsDTO(TypedDict):
     right_lvl: str
     availability_schedule: str
     dont_pack: str
+    portion_weight: str
+    portion_name: str
 
 
 class WaiterDTO(TypedDict):
